.. InstanceLib documentation master file, created by
   sphinx-quickstart on Tue May  4 15:37:22 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to InstanceLib's documentation!
=======================================

Welcome to the documentation of InstanceLib! It includes an :doc:`installation
</intro/installation>` guide, a :doc:`quick tour </intro/usage>`, details how
to prepare your :doc:`dataset </intro/datasets>` and much more - enjoy!

InstanceLib is `open source <https://git.science.uu.nl/mpbron-phd/instancelib>`_ research
software developed by :ref:`researchers <intro/about:research team>` at Utrecht
University and is published under the `GNU LGPL v3
<https://git.science.uu.nl/mpbron-phd/instancelib/-/blob/master/LICENSE>`_.

.. toctree::
   :maxdepth: 1
   :caption: Introduction:

   intro/installation
   intro/datasets
   intro/usage

.. toctree::
   :maxdepth: 1
   :caption: Data Model:

   datamodel/instances
   datamodel/providers
   datamodel/labels
   datamodel/enviroments

.. toctree::
   :maxdepth: 1
   :caption: Applications:

   application/feature_ex
   application/machinelearning
   application/pertubation
   



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
